@@ -2,6 +2,7 @@ import os
 import json
 import platform
 
+from .alert import get_alert, get_alerts
 from .device import Device
 from .entity import Entity
 from .zone import Zone
@@ -131,6 +132,76 @@ class Account(Entity):
             return []
         return [Zone(data['id'], data, api=self.api) for data in result]
 
+    def get_alert(self, alert_id, attributes=None, params=None):
+        """:obj:`Alert`: Fetch an Alert by its ID
+
+        Args:
+            alert_id (str): Alert ID.
+            attributes (list): Optional list of attributes to request.
+            params (dict): Optional query parameters.
+        """
+        alert = get_alert(
+            self.api,
+            self._id,
+            alert_id,
+            attributes=attributes,
+            params=params,
+            account_name=self.name,
+        )
+        return alert
+
+    def get_alerts(self, attributes=None, params=None):
+        """:obj:`list` of :obj:`Alert`: Fetch a list of alerts for the account, according to the used params
+
+        Args:
+            attributes (list): Optional list of attributes to request.
+            params (dict): Optional query parameters.
+        """
+        alerts = get_alerts(
+            self.api,
+            self._id,
+            attributes=attributes,
+            params=params,
+            account_name=self.name,
+        )
+        return alerts
+
+    def get_zone_alerts(self, zone_id, attributes=None, params=None):
+        """:obj:`list` of :obj:`Alert`: Fetch a list of alerts for the zone, according to the used params
+
+        Args:
+            zone_id (str): Zone ID.
+            attributes (list): Optional list of attributes to request.
+            params (dict): Optional query parameters.
+        """
+        alerts = get_alerts(
+            self.api,
+            self._id,
+            zone_id=zone_id,
+            attributes=attributes,
+            params=params,
+            account_name=self.name,
+        )
+        return alerts
+
+    def get_device_alerts(self, device_id, attributes=None, params=None):
+        """:obj:`list` of :obj:`Alert`: Fetch a list of alerts for the device, according to the used params
+
+        Args:
+            device_id (str): Device ID.
+            attributes (list): Optional list of attributes to request.
+            params (dict): Optional query parameters.
+        """
+        alerts = get_alerts(
+            self.api,
+            self._id,
+            device_id=device_id,
+            attributes=attributes,
+            params=params,
+            account_name=self.name,
+        )
+        return alerts
+
     def get_setting(self, setting_name):
         """:obj:`Setting`: Finds a setting by its name.
 
