@@ -2,7 +2,7 @@ import json
 import time
 import logging
 
-from .alert import Alert
+from .alert import Alert, get_alerts
 from .entity import Entity
 from .helpers import to_unix_time
 
@@ -134,7 +134,10 @@ class Device(Entity):
         if not result:
             return []
 
-        alerts = [Alert(alert__data["alert_id"], alert__data) for alert__data in result]
+        alerts = [
+            Alert(alert_data["alert_id"], alert_data, device_name=self.name)
+            for alert_data in result
+        ]
         return alerts
 
     @property
@@ -264,6 +267,23 @@ class Device(Entity):
 
         return result[-1]
 
+    def get_alerts(self, attributes=None, params=None):
+        """:obj:`list` of :obj:`Alert`: Fetch a list of alerts for the device, according to the used params
+
+        Args:
+            attributes (list): Optional list of attributes to request.
+            params (dict): Optional query parameters.
+        """
+        alerts = get_alerts(
+            self.api,
+            self.account,
+            device_id=self._id,
+            attributes=attributes,
+            params=params,
+            device_name=self.name,
+        )
+        return alerts
+
     def get_statistics(self, utc_start=None, utc_end=None, params=None):
         """GET statistics endpoint abstraction.
 
